@@ -1,7 +1,7 @@
 /* gnopiui.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -140,89 +140,18 @@ gn_show_message (const gchar *msg)
     gtk_widget_destroy (dialog);
 }
 
-void
-gn_settings_response (GtkDialog *dialog,
-			gint       response_id,
-			gpointer   user_data);
-
-
-static gint
-gn_delete_emit_response_cancel (GtkDialog *dialog,
-				   GdkEventAny *event,
-				   gpointer data);
-
-static void
-gn_load_gnopernicus_credits (void)
-{
-    GladeXML *xml = NULL;
-    static GtkWidget *credit = NULL;
-    
-    xml = gn_load_interface ("about.glade2", "dl_credit");
-    credit   = glade_xml_get_widget (xml, "dl_credit");
-    
-    if (credit)
-	gtk_widget_show (credit);
-	
-    if (xml) 
-	g_object_unref (G_OBJECT (xml));
-
-    g_signal_connect (credit, "response",
-		      G_CALLBACK (gn_settings_response), NULL);
-    g_signal_connect (credit, "delete_event",
-                      G_CALLBACK (gn_delete_emit_response_cancel), NULL);	
-
-    g_signal_connect (credit, "destroy",
-		      G_CALLBACK (gtk_widget_destroyed),
-		      &credit);
-}
-
-void
-gn_settings_response (GtkDialog *dialog,
-			gint       response_id,
-			gpointer   user_data)
-{
-    if (response_id == GTK_RESPONSE_ACCEPT)
-    {
-	gn_load_gnopernicus_credits ();
-    }
-    else
-	gtk_widget_hide ((GtkWidget*)dialog);
-    
-}
-
-
-static gint
-gn_delete_emit_response_cancel (GtkDialog *dialog,
-				   GdkEventAny *event,
-				   gpointer data)
-{
-    gtk_dialog_response (GTK_DIALOG (dialog),
-			 GTK_RESPONSE_CANCEL);
-    return TRUE; /* Do not destroy */
-}
-
-
 static void
 gn_load_gnopernicus_about (void)
 {
     GladeXML 		*xml;
     gchar		*file = NULL;
-    gchar 		*name = NULL;
-    static GtkWidget 	*about = NULL;
-    static GtkWidget 	*lb_name = NULL;
-    static GtkWidget 	*im_logo = NULL;
+    GtkWidget		*about = NULL;
+    GdkPixbuf		*logo = NULL;
     
     xml = gn_load_interface ("about.glade2", "dl_about");
 
-    if (about) 
-    {
-    	gtk_window_set_screen (
-			GTK_WINDOW (about),
-			gtk_widget_get_screen (GTK_WIDGET (w_gnopernicus)));
-			gtk_window_present (GTK_WINDOW (about));
-	return;
-    }
-    
+    about = glade_xml_get_widget (xml, "dl_about");
+
     file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
 				     "gnopernicus.png", 
 				      TRUE, NULL);
@@ -233,38 +162,21 @@ gn_load_gnopernicus_about (void)
 				     "gnome-about-logo.png", 
 				      TRUE, NULL);
     }
-    
-    about   = glade_xml_get_widget (xml, "dl_about");
-    lb_name = glade_xml_get_widget (xml, "lb_name");
-    im_logo = glade_xml_get_widget (xml, "im_pixmap");
-    
-    name = g_strdup_printf ("<span size=\"xx-large\"><b>gnopernicus %s</b>"
-			    "</span>", 
-			    VERSION);
-			    
-    gtk_label_set_markup (GTK_LABEL (lb_name), name);
-    g_free (name);
-    
+
+    g_object_set (about, "version", VERSION, NULL);
+
     if (file)
     {
-	gtk_image_set_from_file (GTK_IMAGE (im_logo), file);
-	g_free (file);
+	logo = gdk_pixbuf_new_from_file (file, NULL);
+	g_object_set (about, "logo", logo, NULL);
     }
-    
-    g_signal_connect (about, "response",
-		      G_CALLBACK (gn_settings_response), NULL);
-    g_signal_connect (about, "delete_event",
-                      G_CALLBACK (gn_delete_emit_response_cancel), NULL);	
-		
+
     if (xml) 
 	g_object_unref (G_OBJECT (xml));
 
-    gtk_window_set_wmclass (GTK_WINDOW (about), "gnopernicus", "GNOPERNICUS");
-    gtk_window_set_screen (GTK_WINDOW (about), gtk_widget_get_screen (GTK_WIDGET (w_gnopernicus)));
-    
-    g_signal_connect (about, "destroy",
-		      G_CALLBACK (gtk_widget_destroyed),
-		      &about);
+    if (logo)
+	g_object_unref (logo);
+
     gtk_widget_show (about);
 }
 
