@@ -1,7 +1,7 @@
 /* SRMessages.h
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -32,17 +32,6 @@
 
 GLogLevelFlags sru_log_flags 		= 0;
 GLogLevelFlags sru_log_stack_flags 	= 0;
-/*static guint sru_log_handler 		= 0;*/
-
-/*
-static void
-sru_log (const gchar *log_domain,
-	 GLogLevelFlags log_level,
-	 const gchar *message,
-	 gpointer user_data)
-{
-}
-*/
 
 static G_CONST_RETURN gchar*
 sru_log_get_env_var (const gchar *env)
@@ -124,21 +113,6 @@ sru_log_get_flags_from_env_var (const gchar *env)
 gboolean
 sru_log_init ()
 {
-/*    GLogLevelFlags flags = 0;
-    
-    flags = sru_log_get_flags_from_env_var (GNOPERNICUS_DEBUG);
-    flags ^= (G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_WARNING |
-		G_LOG_LEVEL_MESSAGE | G_LOG_LEVEL_INFO | G_LOG_LEVEL_DEBUG);
-    if (flags)
-    {
-	sru_log_handler = g_log_set_handler (G_LOG_DOMAIN,
-                                            flags | G_LOG_FLAG_FATAL,
-					    sru_log, NULL);
-	return sru_log_handler != 0;
-    }
-    
-    return TRUE;
-*/
     sru_log_flags = sru_log_get_flags_from_env_var (GNOPERNICUS_DEBUG);
     sru_log_stack_flags = sru_log_get_flags_from_env_var (GNOPERNICUS_DEBUG_STACK);
     return TRUE;
@@ -147,11 +121,6 @@ sru_log_init ()
 gboolean
 sru_log_terminate ()
 {
-/*
-    if (sru_log_handler)
-	g_log_remove_handler (G_LOG_DOMAIN, sru_log_handler);
-    sru_log_handler = 0;
-*/
     return TRUE;
 }
 #endif /* SRU_PARANOIA */
